// generated from rosidl_generator_c/resource/idl.h.em
// with input from example_interfaces:msg/Bool.idl
// generated code does not contain a copyright notice

#ifndef EXAMPLE_INTERFACES__MSG__BOOL_H_
#define EXAMPLE_INTERFACES__MSG__BOOL_H_

#include "example_interfaces/msg/detail/bool__struct.h"
#include "example_interfaces/msg/detail/bool__functions.h"
#include "example_interfaces/msg/detail/bool__type_support.h"

#endif  // EXAMPLE_INTERFACES__MSG__BOOL_H_
